@@ -1,4 +1,4 @@
-// Copyright 2021 Datafuse Labs.
+// Copyright 2022 Datafuse Labs.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,16 +13,19 @@
 // limitations under the License.
 
 use anyhow::Result;
+use log::warn;
 use opendal::Operator;
 use opendal_test::services::fs;
 
 use super::BehaviorTest;
 
 #[tokio::test]
-async fn test_fs() -> Result<()> {
+async fn behavior() -> Result<()> {
+    super::init_logger();
+
     let acc = fs::new().await?;
     if acc.is_none() {
-        println!("OPENDAL_FS_TEST not set, ignore");
+        warn!("OPENDAL_FS_TEST not set, ignore");
         return Ok(());
     }
 
