@@ -13,16 +13,19 @@
 // limitations under the License.
 
 use anyhow::Result;
+use log::warn;
 use opendal::Operator;
 use opendal_test::services::s3;
 
 use super::BehaviorTest;
 
 #[tokio::test]
-async fn test_s3() -> Result<()> {
+async fn behavior() -> Result<()> {
+    super::init_logger();
+
     let acc = s3::new().await?;
     if acc.is_none() {
-        println!("OPENDAL_S3_TEST not set, ignore");
+        warn!("OPENDAL_S3_TEST not set, ignore");
         return Ok(());
     }
 
